# Stylus

To use this language, use the class "language-stylus".

## Full Example

    /*!
     * Adds the given numbers together.
     */
    /*
     * Adds the given numbers together.
     */
    // I'm a comment!
    body {
    	font: 12px Helvetica, Arial, sans-serif;
    }
    a.button {
    	-webkit-border-radius: 5px;
    	-moz-border-radius: 5px;
    	border-radius: 5px;
    }

    body
    	font: 12px Helvetica, Arial, sans-serif;

    a.button:after
    	-webkit-border-radius: 5px;
    	-moz-border-radius: 5px;
    	border-radius: 5px;

    body
    	font: 12px Helvetica, Arial, sans-serif

    a.link > button#test, input[type=button], a:after
    	-webkit-border-radius: 5px
    	-moz-border-radius: 5px
    	border-radius: 5px

    font-size = 14px
    font = font-size "Lucida Grande", Arial

    body {
    	padding: 50px;
    	font: 14px/1.4 fonts;
    }

    border-radius()
    	-webkit-border-radius arguments
    	-moz-border-radius arguments
    	border-radius arguments

    body
    	font 12px Helvetica, Arial, sans-serif

    a.button
    	border-radius(5px)

    @media (max-width: 30em) {
    	body {
    		color: #fff;
    	}
    }

    @media (max-width: 500px)
    	.foo
    		color: #000

    	@media (min-width: 100px), (min-height: 200px)
    		.foo
    			color: #100

    sum(nums...)
    	sum = 0
    	sum += n for n in nums

    sum(1 2 3 4)
    // => 10

## Known failures

There are certain edge cases where Prism will fail. There are always such cases in every regex-based syntax highlighter. However, Prism dares to be open and honest about them. If a failure is listed here, it doesn’t mean it will never be fixed. This is more of a “known bugs” list, just with a certain type of bug.

### Comment-like substrings

    "foo // bar";